@@ -11,6 +11,8 @@ print library_path
 
 
 def install_virtualenv_and_package(package_file, install_path="", virtualenv=True):
+    print package_file
+    print install_path
 
     # install_path it's not used yet
     install_path += virtualenv_path
@@ -43,7 +45,7 @@ def check_virtualenv(path):
 
 
 def install_virtualenv(install_path=""):
-    output = subprocess.check_call(["virtualenv", install_path + "env"])
+    output = subprocess.check_call(["virtualenv", install_path])
     print output
 
 
